==> hs-cpphs-1.16_1.txz: usr/local/lib/cabal/ghc-7.6.3/cpphs-1.16/register.sh <==
#!/bin/sh
echo 'name: cpphs
version: 1.16
id: cpphs-1.16-702db2d1d12c34f35eea74b6f0cf6aa5

license: LGPL
copyright: 2004-2012, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
stability:
homepage: http://haskell.org/cpphs/
package-url:
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
                Text.ParserCombinators.HuttonMeijer
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/cpphs-1.16
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/cpphs-1.16
              /usr/local/lib
hs-libraries: HScpphs-1.16
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-f7bdc8987bd5928e0ee6e8cc8b246a88
         directory-1.2.0.1-9eaa01c28e06d5c85f67c966a03a9e57
         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
         old-time-1.1.0.1-2f8ea093d0c7014780a8a5772f948883
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/cpphs-1.16/html/cpphs.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/cpphs-1.16/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-cpphs-1.18.5_1.txz: usr/local/lib/cabal/ghc-7.8.3/cpphs-1.18.5/register.sh <==
#!/bin/sh
export PATH='/usr/local/libexec/ccache:/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: cpphs
version: 1.18.5
id: cpphs-1.18.5-21dcf22ce80159f3d8dc3f6f6d92b676

license: LGPL
copyright: 2004-2014, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
stability:
homepage: http://projects.haskell.org/cpphs/
package-url:
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.8.3/cpphs-1.18.5
library-dirs: /usr/local/lib/cabal/ghc-7.8.3/cpphs-1.18.5
              /usr/local/lib
hs-libraries: HScpphs-1.18.5
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.7.0.1-812360bc88c9859b8259f0d90b6e2faa
         directory-1.2.1.0-7bc3edddb9ec0c2616861a4f1c5f6c54
         old-locale-1.0.0.6-09baf1dbc5be8338e5eba7c5bb515505
         old-time-1.1.0.2-82f33d6e3ad1bf310652027f3726eaa8
         polyparse-1.9-e5d39531fce3e66555103149d2a92d4a
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.8.3/cpphs-1.18.5/html/cpphs.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.8.3/cpphs-1.18.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
